/*
 * $Id: DatabaseBasicMessage.java 348369 2005-11-23 04:51:04Z niallp $
 * $Revision: 348369 $
 * $Date: 2005-11-22 23:51:04 -0500 (Tue, 22 Nov 2005) $
 *
 * ====================================================================
 *
 *  Copyright 2003-2005 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.commons.resources.impl;





/**
 * BasicMessage to allow standard ORM 
 * configuration (no complex keys).
 * 
 * @author James Mitchell
 *
 */
public class DatabaseBasicMessage extends BasicMessage {

    /**
     * Default Constructor.
     */
    public DatabaseBasicMessage() {
        super();
    }

    /**
     * Construct a message for a specified Locale
     * with the specified replacement values.
     *
     * @param locale Locale for this message
     * @param key Message key for this message
     * @param values Array of replacement values
     */
    public DatabaseBasicMessage(String locale, String key, Object[] values) {
        super(key, values);
        this.locale = locale;
        
    }
    
    private String locale = null;

    /**
     * Return the locale for the message.
     *
     * @return Returns the locale.
     */
    public String getLocale() {
        return locale;
    }

    /**
     * Set the locale for the message.
     *
     * @param locale The locale to set.
     */
    public void setLocale(String locale) {
        this.locale = locale;
    }

    /**
     * Set a replacement value for the message.
     *
     * @param value The replacement value.
     */
    public void setValue(String value) {
        setValues(new String[]{value});
    }

    /**
     * Return the replacement value for the message.
     *
     * @return The replacement value.
     */
    public String getValue() {
        Object[] values = getValues();
        if (values == null || values.length < 1) {
            throw new IllegalStateException("The retrived value for msg " + 
                    getKey() + "was null");
        }
        if (values.length > 1) {
            throw new IllegalStateException("There were more than one values " +
                    "retrived value for msg " + 
                    getKey());
        }
        return (String)getValues()[0];
    }
    
    /**
     * Compare this message to another.
     *
     * @param obj The message to compare.
     * @return 'true' if the messages are equal.
     */
    public boolean equals(Object obj) {
        if (obj instanceof DatabaseBasicMessage){
            if (((DatabaseBasicMessage)obj).getKey().equals(getKey()) && 
                    ((DatabaseBasicMessage)obj).getLocale().equals(this.locale)){
                return true;
            }
        }
        return false;
    }

    /**
     * Return the hashcode for the message.
     *
     * @return The message's hash code.
     */
    public int hashCode() {
        return super.hashCode();
    }
}
