/*
 * $Id: BasicMessageTestCase.java 354761 2005-12-07 15:11:58Z niallp $
 * $Revision: 354761 $
 * $Date: 2005-12-07 10:11:58 -0500 (Wed, 07 Dec 2005) $
 *
 * ====================================================================
 *
 *  Copyright 2003-2005 The Apache Software Foundation
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.commons.resources.impl;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * Unit tests for the <code>org.apache.commons.resources.Message</code> class.
 * <p>
 * Orginally based on org.apache.http.action.TestActionMessage, Revision 1.2.
 */
public class BasicMessageTestCase extends TestCase {
    
    protected BasicMessage amWithNoValue = null;
    
    protected BasicMessage amWithOneValue = null;
    
    protected BasicMessage amWithMultipleValues = null;
    
    /**
     * Defines the testcase name for JUnit.
     *
     * @param theName the testcase's name.
     */
    public BasicMessageTestCase(String theName) {
        super(theName);
    }

    /**
     * Start the tests.
     *
     * @param theArgs the arguments. Not used
     */
    public static void main(String[] theArgs) {
        junit.awtui.TestRunner.main(
            new String[] { BasicMessageTestCase.class.getName()});
    }

    /**
     * @return a test suite (<code>TestSuite</code>) that includes all methods
     *         starting with "test"
     */
    public static Test suite() {
        // All methods starting with "test" will be executed in the test suite.
        return new TestSuite(BasicMessageTestCase.class);
    }

    public void setUp() {
        amWithNoValue = new BasicMessage("amWithNoValue");
        amWithOneValue =
            new BasicMessage("amWithOneValue", new String("stringValue"));
        amWithMultipleValues =
            new BasicMessage("amWithOneValue", 
                    new String[]{"stringValue1", "stringValue2", "stringValue3"});
    }

    public void tearDown() {
        amWithNoValue = null;
    }
    
    public void testBasicMessageWithNoValue() {
        
        
        assertTrue(
            "testBasicMessageWithNoValue value is not null",
            amWithNoValue.getValues() == null);
            
        assertTrue(
            "testBasicMessageWithNoValue key is not amWithNoValue",
            amWithNoValue.getKey() == "amWithNoValue");
        
        amWithNoValue = new BasicMessage();

        assertNull(
                "testBasicMessageWithNoValue value is not null",
                amWithNoValue.getValues());
        
    }

    public void testBasicMessageWithAStringValue() {
        Object[] values = amWithOneValue.getValues();
        assertTrue(
            "testBasicMessageWithAStringValue value is not null",
            values != null);
            
        assertTrue(
            "testBasicMessageWithAStringValue value[0] is not the string stringValue",
            values[0].equals("stringValue"));
            
        assertTrue(
            "testBasicMessageWithAStringValue key is not amWithOneValue",
            amWithOneValue.getKey() == "amWithOneValue");
        
        assertEquals("Test toString", amWithOneValue.toString(), "amWithOneValue[stringValue]");
        
        assertEquals("Test toString() (multiple)", 
                amWithMultipleValues.toString(), "amWithOneValue[stringValue1, stringValue2, stringValue3]");
        
    }
}